import { __decorate } from "tslib";
import { bodyFont } from '@microsoft/fast-components';
import { attr, customElement, DOM, FASTElement, observable } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { applyStyleChanges } from '../../utils/utils';
import { PreviewGridStyles as styles } from './preview-grid.styles';
import { PreviewGridTemplate as template } from './preview-grid.template';
let PreviewGrid = class PreviewGrid extends FASTElement {
    constructor() {
        super(...arguments);
        this.prefix = 'zero';
        this.rowData = [
            { make: 'Toyota', model: 'Celica', price: 35000, creationDate: 1617624494293, isCool: true },
            { make: 'Ford', model: 'Mondeo', price: 32000, creationDate: 1617624494295, isCool: false },
            { make: 'Porsche', model: 'Boxter', price: 72000, creationDate: 1619637452397, isCool: false },
            { make: 'Audi', model: 'A6', price: 80000, creationDate: 1617624494293, isCool: true },
            { make: 'Renault', model: 'Clio', price: 20000, creationDate: 1617624494295, isCool: true },
            {
                make: 'Chevrolet',
                model: 'Camaro',
                price: 40000,
                creationDate: 1619637452397,
                isCool: false,
            },
            { make: 'BMW', model: 'Z8', price: 90000, creationDate: 1617624494293, isCool: false },
            { make: 'Suzuki', model: 'Jimny', price: 23000, creationDate: 1617624494295, isCool: false },
            { make: 'Toyota', model: 'Celica', price: 35000, creationDate: 1619637452397, isCool: true },
            { make: 'Ford', model: 'Mondeo', price: 32000, creationDate: 1617624494293, isCool: false },
            { make: 'Porsche', model: 'Boxter', price: 72000, creationDate: 1617624494295, isCool: true },
            { make: 'Audi', model: 'A6', price: 80000, creationDate: 1619637452397, isCool: false },
            { make: 'Renault', model: 'Clio', price: 20000, creationDate: 1617624494293, isCool: false },
            { make: 'Chevrolet', model: 'Camaro', price: 40000, creationDate: 1617624494295, isCool: true },
            { make: 'BMW', model: 'Z8', price: 90000, creationDate: 1619637452397, isCool: true },
            { make: 'Suzuki', model: 'Jimny', price: 23000, creationDate: 1617624494293, isCool: true },
        ];
        this.columnDefs = [
            { field: 'make' },
            { field: 'model' },
            { field: 'price' },
            { field: 'creationDate' },
            { field: 'isCool' },
        ];
        this.gridOptions = {
            defaultColDef: {
                resizable: true,
                filter: true,
            },
            debug: false,
            columnDefs: this.columnDefs,
            rowData: this.rowData,
        };
    }
    setGridOptions() {
        this.grid.gridOptions = this.gridOptions;
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            this.setGridOptions();
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        DOM.queueUpdate(() => {
            this.setGridOptions();
        });
    }
};
__decorate([
    observable
], PreviewGrid.prototype, "grid", void 0);
__decorate([
    attr
], PreviewGrid.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "provider", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "rowData", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "columnDefs", void 0);
__decorate([
    observable
], PreviewGrid.prototype, "gridOptions", void 0);
PreviewGrid = __decorate([
    customElement({
        name: 'preview-grid',
        template,
        styles,
    })
], PreviewGrid);
export { PreviewGrid };
